pub enum RegistryError {
RegistryLock,
TypeMismatch {
type_name: &'static str,
},
TypeNotFound {
type_name: &'static str,
},
}Expand description
Error type for registry operations.
All fallible registry operations return this error type to indicate what went wrong during the operation.
Variants
RegistryLock
Failed to acquire the registry lock (lock poisoning).
This is automatically recovered in most operations, but exposed here for completeness.
TypeMismatch
Type mismatch during downcast (should never happen in practice).
Includes the type name that was requested.
TypeNotFound
The requested type was not found in the registry.
Includes the type name that was requested.